@@ -4,18 +4,18 @@ use Pcore -const;
 
 const our $TYPE_COUNTRY    => 1;
 const our $TYPE_COUNTRY_V6 => 2;
-const our $TYPE_COUNTRY2   => 3;
-const our $TYPE_CITY       => 4;
-const our $TYPE_CITY_V6    => 5;
+const our $TYPE_CITY       => 3;
+const our $TYPE_CITY_V6    => 4;
+const our $TYPE_COUNTRY2   => 5;
 const our $TYPE_CITY2      => 6;
 
 const our $RES => {
     $TYPE_COUNTRY    => [ '/data/geoip_country.dat',    'https://geolite.maxmind.com/download/geoip/database/GeoLiteCountry/GeoIP.dat.gz' ],
     $TYPE_COUNTRY_V6 => [ '/data/geoip_country_v6.dat', 'https://geolite.maxmind.com/download/geoip/database/GeoIPv6.dat.gz' ],
-    $TYPE_COUNTRY2   => [ '/data/geoip2_country.dat',   'https://geolite.maxmind.com/download/geoip/database/GeoLite2-Country.mmdb.gz' ],
     $TYPE_CITY       => [ '/data/geoip_city.dat',       'https://geolite.maxmind.com/download/geoip/database/GeoLiteCity.dat.gz' ],
     $TYPE_CITY_V6    => [ '/data/geoip_city_v6.dat',    'https://geolite.maxmind.com/download/geoip/database/GeoLiteCityv6-beta/GeoLiteCityv6.dat.gz' ],
-    $TYPE_CITY2      => [ '/data/geoip2_city.dat',      'http://geolite.maxmind.com/download/geoip/database/GeoLite2-City.mmdb.gz' ],
+    $TYPE_COUNTRY2   => [ '/data/geoip2_country.mmdb',  'https://geolite.maxmind.com/download/geoip/database/GeoLite2-Country.mmdb.gz' ],
+    $TYPE_CITY2      => [ '/data/geoip2_city.mmdb',     'http://geolite.maxmind.com/download/geoip/database/GeoLite2-City.mmdb.gz' ],
 };
 
 my $H;
